/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets;

import java.io.*;
import javax.servlet.*;
import javax.servlet.http.*;
import org.apache.log4j.*;
import com.silverwrist.venice.core.*;
import com.silverwrist.venice.servlets.format.*;

public class SystemAdmin extends VeniceServlet
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  private static Category logger = Category.getInstance(SIGAdmin.class.getName());

  /*--------------------------------------------------------------------------------
   * Internal functions
   *--------------------------------------------------------------------------------
   */

  private SystemAdminTop makeSystemAdminTop() throws ServletException
  {
    final String desired_name = "SystemAdminTop";
    MenuPanelCache cache = MenuPanelCache.getMenuPanelCache(getServletContext());

    if (!(cache.isCached(desired_name)))
    { // create a template and save it off
      SystemAdminTop template = new SystemAdminTop();
      cache.saveTemplate(template);

    } // end if

    // return a new copy
    return (SystemAdminTop)(cache.getNewMenuPanel(desired_name));

  } // end makeSystemAdminTop

  /*--------------------------------------------------------------------------------
   * Overrides from class HttpServlet
   *--------------------------------------------------------------------------------
   */

  public String getServletInfo()
  {
    String rc = "SystemAdmin servlet - Administrative functions for the entire system\n"
              + "Part of the Venice Web Communities System\n";
    return rc;

  } // end getServletInfo

  /*--------------------------------------------------------------------------------
   * Overrides from class VeniceServlet
   *--------------------------------------------------------------------------------
   */

  protected VeniceContent doVeniceGet(HttpServletRequest request, VeniceEngine engine,
				      UserContext user, RenderData rdat)
      throws ServletException, IOException, VeniceServletResult
  {
    // decide what to do based on the "cmd" parameter
    String cmd = getStandardCommandParam(request);
    if (logger.isDebugEnabled())
      logger.debug("SystemAdmin/doGet command value = " + cmd);

    // TODO: command handling

    if (!(user.hasAdminAccess()))
      return new ErrorBox("Access Error","You do not have permission to administer the system.",null);

    setMyLocation(request,"sysadmin");
    return makeSystemAdminTop();

  } // end doVeniceGet

} // end class SystemAdmin
